==> qmmp-0.9.2-1.00.tar.gz: qmmp-0.9.2/src/plugins/Input/vorbis/translations/vorbis_plugin_he.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="he">
<context>
    <name>DecoderVorbisFactory</name>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="53"/>
        <source>Ogg Vorbis Plugin</source>
        <translation>תוספת Ogg Vorbis</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="56"/>
        <source>Ogg Vorbis Files</source>
        <translation>קבצי Ogg Vorbis</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="135"/>
        <source>About Ogg Vorbis Audio Plugin</source>
        <translation>אודות תוספת שמע Ogg Vorbis</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="136"/>
        <source>Qmmp Ogg Vorbis Audio Plugin</source>
        <translation>תוספת שמע Ogg Vorbis של Qmmp</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="137"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>חוברה על ידי: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;‎</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="138"/>
        <source>Source code based on mq3 project</source>
        <translation>קוד מקוד מבוסס על פרויקט mq3</translation>
    </message>
</context>
<context>
    <name>VorbisMetaDataModel</name>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="51"/>
        <source>Length</source>
        <translation>אריכות</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="52"/>
        <source>Sample rate</source>
        <translation>שיעור דגימה</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="52"/>
        <source>Hz</source>
        <translation>הרץ</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="53"/>
        <source>Channels</source>
        <translation>ערוצים</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="54"/>
        <source>Bitrate</source>
        <translation>שיעור סיביות</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="54"/>
        <source>kbps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="55"/>
        <source>File size</source>
        <translation>גודל קובץ</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="55"/>
        <source>KB</source>
        <translation>ק״ב</translation>
    </message>
</context>
</TS>

==> qmmp_0.10.5.orig.tar.gz: qmmp-0.10.5/src/plugins/Input/vorbis/translations/vorbis_plugin_he.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="he">
<context>
    <name>DecoderVorbisFactory</name>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="55"/>
        <source>Ogg Vorbis Plugin</source>
        <translation>תוסף Ogg Vorbis</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="58"/>
        <source>Ogg Vorbis Files</source>
        <translation>קבצי Ogg Vorbis</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="137"/>
        <source>About Ogg Vorbis Audio Plugin</source>
        <translation>אודות תוסף שמע Ogg Vorbis</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="138"/>
        <source>Qmmp Ogg Vorbis Audio Plugin</source>
        <translation>תוסף שמע Ogg Vorbis של Qmmp</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="139"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>חובר על ידי: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;‎</translation>
    </message>
    <message>
        <location filename="../decodervorbisfactory.cpp" line="140"/>
        <source>Source code based on mq3 project</source>
        <translation>קוד מקוד מבוסס על פרויקט mq3</translation>
    </message>
</context>
<context>
    <name>VorbisMetaDataModel</name>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="58"/>
        <source>Length</source>
        <translation>אריכות</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="59"/>
        <source>Sample rate</source>
        <translation>שיעור דגימה</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="59"/>
        <source>Hz</source>
        <translation>הרץ</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="60"/>
        <source>Channels</source>
        <translation>ערוצים</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="61"/>
        <source>Bitrate</source>
        <translation>שיעור סיביות</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="61"/>
        <source>kbps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="62"/>
        <source>File size</source>
        <translation>גודל קובץ</translation>
    </message>
    <message>
        <location filename="../vorbismetadatamodel.cpp" line="62"/>
        <source>KB</source>
        <translation>ק״ב</translation>
    </message>
</context>
</TS>
